# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1573
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

from visier_api_data_in.api.data_upload_api import DataUploadApi


class TestDataUploadApi(unittest.TestCase):
    """DataUploadApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DataUploadApi()

    def tearDown(self) -> None:
        pass

    def test_v1_data_upload_files_filename_put(self) -> None:
        """Test case for v1_data_upload_files_filename_put

        Upload a data file to Visier
        """
        pass

    def test_v1alpha_op_data_uploads_download_source_files_get(self) -> None:
        """Test case for v1alpha_op_data_uploads_download_source_files_get

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1573
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from visier_api_core import ApiClient, ApiResponse, RequestSerialized, RESTResponseType

from pydantic import Field, StrictStr
from typing import Optional
from typing_extensions import Annotated
from visier_api_data_in.models.key_pair_delete_response_dto import KeyPairDeleteResponseDTO
from visier_api_data_in.models.key_pair_generate_request_dto import KeyPairGenerateRequestDTO
from visier_api_data_in.models.public_key_dto import PublicKeyDTO
from visier_api_data_in.models.public_keys_dto import PublicKeysDTO
import visier_api_data_in.models


class PGPKeyApi:
    """
    This class provides methods to make requests to the Visier API.
    It uses the ApiClient to handle the HTTP requests and responses.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def delete_pgp_key_pair(
        self,
        key_id: Annotated[StrictStr, Field(description="The key ID of the generated key pair in 16-letter hexadecimal format, including leading zeros.")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> KeyPairDeleteResponseDTO:
        """Delete a PGP key pair

        Delete a PGP key pair using a key ID.

        :param key_id: The key ID of the generated key pair in 16-letter hexadecimal format, including leading zeros. (required)
        :type key_id: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_pgp_key_pair_serialize(
            key_id=key_id,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KeyPairDeleteResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def delete_pgp_key_pair_with_http_info(
        self,
        key_id: Annotated[StrictStr, Field(description="The key ID of the generated key pair in 16-letter hexadecimal format, including leading zeros.")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[KeyPairDeleteResponseDTO]:
        """Delete a PGP key pair

        Delete a PGP key pair using a key ID.

        :param key_id: The key ID of the generated key pair in 16-letter hexadecimal format, including leading zeros. (required)
        :type key_id: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_pgp_key_pair_serialize(
            key_id=key_id,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KeyPairDeleteResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def delete_pgp_key_pair_without_preload_content(
        self,
        key_id: Annotated[StrictStr, Field(description="The key ID of the generated key pair in 16-letter hexadecimal format, including leading zeros.")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete a PGP key pair

        Delete a PGP key pair using a key ID.

        :param key_id: The key ID of the generated key pair in 16-letter hexadecimal format, including leading zeros. (required)
        :type key_id: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_pgp_key_pair_serialize(
            key_id=key_id,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "KeyPairDeleteResponseDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_pgp_key_pair_serialize(
        self,
        key_id,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if key_id is not None:
            _path_params['keyID'] = key_id
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/v1/api/pgpkey/{keyID}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def generate_pgp_key_pair(
        self,
        key_pair_generate_request_dto: KeyPairGenerateRequestDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PublicKeyDTO:
        """Download a public encryption key

        Generate a key pair and retrieve the public key that you can use to encrypt your data to send to Visier.     In the request body, optionally set the UTC expiration date for the key pair in ISO-8601 format. Must be between 2 and 10 years. Default is 2 years.

        :param key_pair_generate_request_dto: (required)
        :type key_pair_generate_request_dto: KeyPairGenerateRequestDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._generate_pgp_key_pair_serialize(
            key_pair_generate_request_dto=key_pair_generate_request_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicKeyDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def generate_pgp_key_pair_with_http_info(
        self,
        key_pair_generate_request_dto: KeyPairGenerateRequestDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PublicKeyDTO]:
        """Download a public encryption key

        Generate a key pair and retrieve the public key that you can use to encrypt your data to send to Visier.     In the request body, optionally set the UTC expiration date for the key pair in ISO-8601 format. Must be between 2 and 10 years. Default is 2 years.

        :param key_pair_generate_request_dto: (required)
        :type key_pair_generate_request_dto: KeyPairGenerateRequestDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._generate_pgp_key_pair_serialize(
            key_pair_generate_request_dto=key_pair_generate_request_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicKeyDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def generate_pgp_key_pair_without_preload_content(
        self,
        key_pair_generate_request_dto: KeyPairGenerateRequestDTO,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Download a public encryption key

        Generate a key pair and retrieve the public key that you can use to encrypt your data to send to Visier.     In the request body, optionally set the UTC expiration date for the key pair in ISO-8601 format. Must be between 2 and 10 years. Default is 2 years.

        :param key_pair_generate_request_dto: (required)
        :type key_pair_generate_request_dto: KeyPairGenerateRequestDTO
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._generate_pgp_key_pair_serialize(
            key_pair_generate_request_dto=key_pair_generate_request_dto,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicKeyDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _generate_pgp_key_pair_serialize(
        self,
        key_pair_generate_request_dto,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter
        if key_pair_generate_request_dto is not None:
            _body_params = key_pair_generate_request_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/api/pgpkey',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_all_pgp_public_keys(
        self,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PublicKeysDTO:
        """Retrieve all PGP public keys

        Retrieve a list of all PGP public keys in your tenant.

        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_all_pgp_public_keys_serialize(
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicKeysDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def get_all_pgp_public_keys_with_http_info(
        self,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PublicKeysDTO]:
        """Retrieve all PGP public keys

        Retrieve a list of all PGP public keys in your tenant.

        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_all_pgp_public_keys_serialize(
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicKeysDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def get_all_pgp_public_keys_without_preload_content(
        self,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Retrieve all PGP public keys

        Retrieve a list of all PGP public keys in your tenant.

        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_all_pgp_public_keys_serialize(
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicKeysDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_all_pgp_public_keys_serialize(
        self,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/api/pgpkey',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_pgp_public_key(
        self,
        key_id: Annotated[StrictStr, Field(description="The key ID of the generated key pair in 16-letter hexadecimal format, including leading zeros.")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PublicKeyDTO:
        """Retrieve a PGP public key using the key ID

        If you know your PGP key ID, use it to retrieve the PGP public key. To get a list of all key IDs, see `Retrieve all PGP public keys`.

        :param key_id: The key ID of the generated key pair in 16-letter hexadecimal format, including leading zeros. (required)
        :type key_id: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_pgp_public_key_serialize(
            key_id=key_id,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicKeyDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def get_pgp_public_key_with_http_info(
        self,
        key_id: Annotated[StrictStr, Field(description="The key ID of the generated key pair in 16-letter hexadecimal format, including leading zeros.")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PublicKeyDTO]:
        """Retrieve a PGP public key using the key ID

        If you know your PGP key ID, use it to retrieve the PGP public key. To get a list of all key IDs, see `Retrieve all PGP public keys`.

        :param key_id: The key ID of the generated key pair in 16-letter hexadecimal format, including leading zeros. (required)
        :type key_id: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_pgp_public_key_serialize(
            key_id=key_id,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicKeyDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def get_pgp_public_key_without_preload_content(
        self,
        key_id: Annotated[StrictStr, Field(description="The key ID of the generated key pair in 16-letter hexadecimal format, including leading zeros.")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Retrieve a PGP public key using the key ID

        If you know your PGP key ID, use it to retrieve the PGP public key. To get a list of all key IDs, see `Retrieve all PGP public keys`.

        :param key_id: The key ID of the generated key pair in 16-letter hexadecimal format, including leading zeros. (required)
        :type key_id: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_pgp_public_key_serialize(
            key_id=key_id,
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PublicKeyDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_pgp_public_key_serialize(
        self,
        key_id,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if key_id is not None:
            _path_params['keyID'] = key_id
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/api/pgpkey/{keyID}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1573
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

from visier_api_data_in.api.direct_data_intake_api import DirectDataIntakeApi


class TestDirectDataIntakeApi(unittest.TestCase):
    """DirectDataIntakeApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DirectDataIntakeApi()

    def tearDown(self) -> None:
        pass

    def test_commit_transaction(self) -> None:
        """Test case for commit_transaction

        Commit a transaction
        """
        pass

    def test_get_config(self) -> None:
        """Test case for get_config

        Get the direct data intake configuration
        """
        pass

    def test_job_status(self) -> None:
        """Test case for job_status

        Check transaction status
        """
        pass

    def test_object_schema(self) -> None:
        """Test case for object_schema

        Retrieve an object's data load schema
        """
        pass

    def test_put_config(self) -> None:
        """Test case for put_config

        Update the direct data intake configuration
        """
        pass

    def test_rollback_transaction(self) -> None:
        """Test case for rollback_transaction

        Roll back a transaction
        """
        pass

    def test_start_transaction(self) -> None:
        """Test case for start_transaction

        Start a direct data intake transaction
        """
        pass

    def test_upload_file(self) -> None:
        """Test case for upload_file

        Upload files
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1573
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

import visier_api_data_in.models
from visier_api_data_in.models.jira_auth_params_dto import JiraAuthParamsDTO

class TestJiraAuthParamsDTO(unittest.TestCase):
    """JiraAuthParamsDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JiraAuthParamsDTO:
        """Test JiraAuthParamsDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """

        if include_optional:
            return JiraAuthParamsDTO(
                api_token = '',
                connect_params = visier_api_data_in.models.jira_connect_params_dto.JiraConnectParamsDTO(
                    app_key = '', 
                    client_key = '', 
                    shared_secret = '', ),
                host_name = ''
            )
        else:
            return JiraAuthParamsDTO(
        )

    def testJiraAuthParamsDTO(self):
        """Test JiraAuthParamsDTO"""
        def validate_instance(instance):
            JiraAuthParamsDTO.model_validate(inst_req_only)
            instance_deserialized = JiraAuthParamsDTO.from_dict(instance.to_dict())
            assert instance == instance_deserialized

        inst_req_only = self.make_instance(include_optional=False)
        validate_instance(inst_req_only)

        inst_req_and_optional = self.make_instance(include_optional=True)
        validate_instance(inst_req_and_optional)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1573
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_data_in.models.data_provider_auth_params_dto import DataProviderAuthParamsDTO
from visier_api_data_in.models.data_provider_basic_information_dto import DataProviderBasicInformationDTO
from visier_api_data_in.models.data_provider_basic_metadata_dto import DataProviderBasicMetadataDTO
from typing import Optional, Set
from typing_extensions import Self

class DataProviderAuthInformationDTO(BaseModel):
    """
    DataProviderAuthInformationDTO
    """ # noqa: E501
    data_provider_auth_params: Optional[DataProviderAuthParamsDTO] = Field(default=None, description="The authentication information for the credential.", alias="dataProviderAuthParams")
    data_provider_basic_information: Optional[DataProviderBasicInformationDTO] = Field(default=None, description="The display name and description for the credential.", alias="dataProviderBasicInformation")
    data_provider_metadata: Optional[DataProviderBasicMetadataDTO] = Field(default=None, alias="dataProviderMetadata")
    __properties: ClassVar[List[str]] = ["dataProviderAuthParams", "dataProviderBasicInformation", "dataProviderMetadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DataProviderAuthInformationDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of data_provider_auth_params
        if self.data_provider_auth_params:
            _dict['dataProviderAuthParams'] = self.data_provider_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of data_provider_basic_information
        if self.data_provider_basic_information:
            _dict['dataProviderBasicInformation'] = self.data_provider_basic_information.to_dict()
        # override the default output from pydantic by calling `to_dict()` of data_provider_metadata
        if self.data_provider_metadata:
            _dict['dataProviderMetadata'] = self.data_provider_metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DataProviderAuthInformationDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "dataProviderAuthParams": DataProviderAuthParamsDTO.from_dict(obj["dataProviderAuthParams"]) if obj.get("dataProviderAuthParams") is not None else None,
            "dataProviderBasicInformation": DataProviderBasicInformationDTO.from_dict(obj["dataProviderBasicInformation"]) if obj.get("dataProviderBasicInformation") is not None else None,
            "dataProviderMetadata": DataProviderBasicMetadataDTO.from_dict(obj["dataProviderMetadata"]) if obj.get("dataProviderMetadata") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1573
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from visier_api_core import ApiClient, ApiResponse, RequestSerialized, RESTResponseType

from pydantic import Field, StrictBytes, StrictStr
from typing import Optional, Tuple, Union
from typing_extensions import Annotated
from visier_api_data_in.models.status import Status
import visier_api_data_in.models


class DataUploadApi:
    """
    This class provides methods to make requests to the Visier API.
    It uses the ApiClient to handle the HTTP requests and responses.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def v1_data_upload_files_filename_put(
        self,
        filename: Annotated[StrictStr, Field(description="The filename of the data file to upload, including the file extension (such as .zip or .csv).")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        body: Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Status:
        """Upload a data file to Visier

        Use this API to upload data files to Visier. You can upload ZIP, CSV, XLS, and XLSX filetypes in plaintext or encrypted with Visier's PGP key.   Use of this API requires client redirect. This API redirects requests directly to Visier's upload infrastructure to support long-running uploads.   To ensure efficient uploading, we recommend that you use an HTTP client that supports the 100 Continue status code.   The maximum file upload size is 500 MB. We recommend using SFTP for larger file sizes.

        :param filename: The filename of the data file to upload, including the file extension (such as .zip or .csv). (required)
        :type filename: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param body:
        :type body: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._v1_data_upload_files_filename_put_serialize(
            filename=filename,
            target_tenant_id=target_tenant_id,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '307': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def v1_data_upload_files_filename_put_with_http_info(
        self,
        filename: Annotated[StrictStr, Field(description="The filename of the data file to upload, including the file extension (such as .zip or .csv).")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        body: Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Status]:
        """Upload a data file to Visier

        Use this API to upload data files to Visier. You can upload ZIP, CSV, XLS, and XLSX filetypes in plaintext or encrypted with Visier's PGP key.   Use of this API requires client redirect. This API redirects requests directly to Visier's upload infrastructure to support long-running uploads.   To ensure efficient uploading, we recommend that you use an HTTP client that supports the 100 Continue status code.   The maximum file upload size is 500 MB. We recommend using SFTP for larger file sizes.

        :param filename: The filename of the data file to upload, including the file extension (such as .zip or .csv). (required)
        :type filename: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param body:
        :type body: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._v1_data_upload_files_filename_put_serialize(
            filename=filename,
            target_tenant_id=target_tenant_id,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '307': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def v1_data_upload_files_filename_put_without_preload_content(
        self,
        filename: Annotated[StrictStr, Field(description="The filename of the data file to upload, including the file extension (such as .zip or .csv).")],
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        body: Optional[Union[StrictBytes, StrictStr, Tuple[StrictStr, StrictBytes]]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Upload a data file to Visier

        Use this API to upload data files to Visier. You can upload ZIP, CSV, XLS, and XLSX filetypes in plaintext or encrypted with Visier's PGP key.   Use of this API requires client redirect. This API redirects requests directly to Visier's upload infrastructure to support long-running uploads.   To ensure efficient uploading, we recommend that you use an HTTP client that supports the 100 Continue status code.   The maximum file upload size is 500 MB. We recommend using SFTP for larger file sizes.

        :param filename: The filename of the data file to upload, including the file extension (such as .zip or .csv). (required)
        :type filename: str
        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param body:
        :type body: bytearray
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._v1_data_upload_files_filename_put_serialize(
            filename=filename,
            target_tenant_id=target_tenant_id,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '307': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _v1_data_upload_files_filename_put_serialize(
        self,
        filename,
        target_tenant_id,
        body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if filename is not None:
            _path_params['filename'] = filename
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter
        if body is not None:
            # convert to byte array if the input is a file name (str)
            if isinstance(body, str):
                with open(body, "rb") as _fp:
                    _body_params = _fp.read()
            else:
                _body_params = body


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/v1/data/upload/files/{filename}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def v1alpha_op_data_uploads_download_source_files_get(
        self,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> bytearray:
        """v1alpha_op_data_uploads_download_source_files_get


        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._v1alpha_op_data_uploads_download_source_files_get_serialize(
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "bytearray",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        ).data


    @validate_call
    def v1alpha_op_data_uploads_download_source_files_get_with_http_info(
        self,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[bytearray]:
        """v1alpha_op_data_uploads_download_source_files_get


        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._v1alpha_op_data_uploads_download_source_files_get_serialize(
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "bytearray",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            model_package=visier_api_data_in.models,
            response_data=response_data,
            response_types_map=_response_types_map
        )


    @validate_call
    def v1alpha_op_data_uploads_download_source_files_get_without_preload_content(
        self,
        target_tenant_id: Annotated[Optional[StrictStr], Field(description="Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """v1alpha_op_data_uploads_download_source_files_get


        :param target_tenant_id: Optionally, specify the tenant that you want to execute the API call on. This defines the tenant that you're logged into. If omitted, the request uses the administrating tenant as the login tenant.
        :type target_tenant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._v1alpha_op_data_uploads_download_source_files_get_serialize(
            target_tenant_id=target_tenant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "bytearray",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _v1alpha_op_data_uploads_download_source_files_get_serialize(
        self,
        target_tenant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if target_tenant_id is not None:
            _header_params['TargetTenantID'] = target_tenant_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/zip', 
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'CookieAuth', 
            'ApiKeyAuth', 
            'OAuth2Auth', 
            'OAuth2Auth', 
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1alpha/op/data/uploads/download-source-files',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# flake8: noqa

# import apis into api package
from visier_api_data_in.api.data_and_job_handling_api import DataAndJobHandlingApi
from visier_api_data_in.api.data_intake_api import DataIntakeApi
from visier_api_data_in.api.data_upload_api import DataUploadApi
from visier_api_data_in.api.direct_data_intake_api import DirectDataIntakeApi
from visier_api_data_in.api.pgp_key_api import PGPKeyApi




# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1573
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "visier-api-data-in"
VERSION = "0.99201.1573"
PYTHON_REQUIRES = ">=3.8"
REQUIRES = [
    "visier-api-core ~= 0.99201.1573",
]

setup(
    name=NAME,
    version=VERSION,
    description="Visier Data In APIs",
    author="Visier",
    author_email="alpine@visier.com",
    url="",
    keywords=["Visier", "Visier-SDK", "Visier Data In APIs"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache License, Version 2.0",
    long_description_content_type='text/markdown',
    long_description="""\
    Visier APIs for sending data to Visier and running data load jobs.
    """,  # noqa: E501
    package_data={"visier_api_data_in": ["py.typed"]},
)



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 22222222.99201.1573
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_data_in.models.adp_auth_params_dto import AdpAuthParamsDTO
from visier_api_data_in.models.bamboo_auth_params_dto import BambooAuthParamsDTO
from visier_api_data_in.models.basic_s3_auth_params_dto import BasicS3AuthParamsDTO
from visier_api_data_in.models.big_query_auth_params_dto import BigQueryAuthParamsDTO
from visier_api_data_in.models.copy_s3_auth_params_dto import CopyS3AuthParamsDTO
from visier_api_data_in.models.dayforce_v2_auth_params_dto import DayforceV2AuthParamsDTO
from visier_api_data_in.models.dimensions_auth_params_dto import DimensionsAuthParamsDTO
from visier_api_data_in.models.fusion_auth_params_dto import FusionAuthParamsDTO
from visier_api_data_in.models.gong_auth_params_dto import GongAuthParamsDTO
from visier_api_data_in.models.google_sheets_auth_params_dto import GoogleSheetsAuthParamsDTO
from visier_api_data_in.models.google_workspace_auth_params_dto import GoogleWorkspaceAuthParamsDTO
from visier_api_data_in.models.greenhouse_auth_params_dto import GreenhouseAuthParamsDTO
from visier_api_data_in.models.icims_auth_params_dto import IcimsAuthParamsDTO
from visier_api_data_in.models.internal_s3_auth_params_dto import InternalS3AuthParamsDTO
from visier_api_data_in.models.jdbc_auth_params_dto import JdbcAuthParamsDTO
from visier_api_data_in.models.jira_auth_params_dto import JiraAuthParamsDTO
from visier_api_data_in.models.lever_auth_params_dto import LeverAuthParamsDTO
from visier_api_data_in.models.medallia_auth_params_dto import MedalliaAuthParamsDTO
from visier_api_data_in.models.microsoft365_auth_params_dto import Microsoft365AuthParamsDTO
from visier_api_data_in.models.my_sql_auth_params_dto import MySqlAuthParamsDTO
from visier_api_data_in.models.namely_auth_params_dto import NamelyAuthParamsDTO
from visier_api_data_in.models.oracle_db_auth_params_dto import OracleDbAuthParamsDTO
from visier_api_data_in.models.qualtrics_auth_params_dto import QualtricsAuthParamsDTO
from visier_api_data_in.models.redshift_auth_params_dto import RedshiftAuthParamsDTO
from visier_api_data_in.models.salesforce_auth_params_dto import SalesforceAuthParamsDTO
from visier_api_data_in.models.salesforce_v2_auth_params_dto import SalesforceV2AuthParamsDTO
from visier_api_data_in.models.service_now_auth_params_dto import ServiceNowAuthParamsDTO
from visier_api_data_in.models.service_now_v2_auth_params_dto import ServiceNowV2AuthParamsDTO
from visier_api_data_in.models.slack_auth_params_dto import SlackAuthParamsDTO
from visier_api_data_in.models.snowflake_auth_params_dto import SnowflakeAuthParamsDTO
from visier_api_data_in.models.sql_server_auth_params_dto import SqlServerAuthParamsDTO
from visier_api_data_in.models.success_factors_auth_params_dto import SuccessFactorsAuthParamsDTO
from visier_api_data_in.models.ultimate_auth_params_dto import UltimateAuthParamsDTO
from visier_api_data_in.models.willow_auth_params_dto import WillowAuthParamsDTO
from visier_api_data_in.models.workday_auth_params_dto import WorkdayAuthParamsDTO
from visier_api_data_in.models.workday_raas_auth_params_dto import WorkdayRaasAuthParamsDTO
from visier_api_data_in.models.zoom_auth_params_dto import ZoomAuthParamsDTO
from typing import Optional, Set
from typing_extensions import Self

class DataProviderAuthParamsDTO(BaseModel):
    """
    DataProviderAuthParamsDTO
    """ # noqa: E501
    adp_auth_params: Optional[AdpAuthParamsDTO] = Field(default=None, alias="adpAuthParams")
    auth_context: Optional[StrictStr] = Field(default=None, alias="authContext")
    bamboo_auth_params: Optional[BambooAuthParamsDTO] = Field(default=None, alias="bambooAuthParams")
    big_query_auth_params: Optional[BigQueryAuthParamsDTO] = Field(default=None, alias="bigQueryAuthParams")
    copy_s3_auth_params: Optional[CopyS3AuthParamsDTO] = Field(default=None, alias="copyS3AuthParams")
    dayforce_v2_auth_params: Optional[DayforceV2AuthParamsDTO] = Field(default=None, alias="dayforceV2AuthParams")
    dimensions_auth_params: Optional[DimensionsAuthParamsDTO] = Field(default=None, alias="dimensionsAuthParams")
    empty_auth_params: Optional[Dict[str, Any]] = Field(default=None, alias="emptyAuthParams")
    fusion_auth_params: Optional[FusionAuthParamsDTO] = Field(default=None, alias="fusionAuthParams")
    gong_auth_params: Optional[GongAuthParamsDTO] = Field(default=None, alias="gongAuthParams")
    google_sheets_auth_params: Optional[GoogleSheetsAuthParamsDTO] = Field(default=None, alias="googleSheetsAuthParams")
    google_workspace_auth_params: Optional[GoogleWorkspaceAuthParamsDTO] = Field(default=None, alias="googleWorkspaceAuthParams")
    greenhouse_auth_params: Optional[GreenhouseAuthParamsDTO] = Field(default=None, alias="greenhouseAuthParams")
    has_updates: Optional[StrictBool] = Field(default=None, alias="hasUpdates")
    icims_auth_params: Optional[IcimsAuthParamsDTO] = Field(default=None, alias="icimsAuthParams")
    internal_s3_auth_params: Optional[InternalS3AuthParamsDTO] = Field(default=None, alias="internalS3AuthParams")
    jdbc_auth_params: Optional[JdbcAuthParamsDTO] = Field(default=None, alias="jdbcAuthParams")
    jira_auth_params: Optional[JiraAuthParamsDTO] = Field(default=None, alias="jiraAuthParams")
    lever_auth_params: Optional[LeverAuthParamsDTO] = Field(default=None, alias="leverAuthParams")
    medallia_auth_params: Optional[MedalliaAuthParamsDTO] = Field(default=None, alias="medalliaAuthParams")
    ms365_auth_params: Optional[Microsoft365AuthParamsDTO] = Field(default=None, alias="ms365AuthParams")
    my_sql_auth_params: Optional[MySqlAuthParamsDTO] = Field(default=None, alias="mySqlAuthParams")
    namely_auth_params: Optional[NamelyAuthParamsDTO] = Field(default=None, alias="namelyAuthParams")
    oracle_db_auth_params: Optional[OracleDbAuthParamsDTO] = Field(default=None, alias="oracleDbAuthParams")
    provider: Optional[StrictStr] = Field(default=None, description="The data provider associated with the credential.")
    qualtrics_auth_params: Optional[QualtricsAuthParamsDTO] = Field(default=None, alias="qualtricsAuthParams")
    redshift_auth_params: Optional[RedshiftAuthParamsDTO] = Field(default=None, alias="redshiftAuthParams")
    s3_auth_params: Optional[BasicS3AuthParamsDTO] = Field(default=None, alias="s3AuthParams")
    salesforce_auth_params: Optional[SalesforceAuthParamsDTO] = Field(default=None, alias="salesforceAuthParams")
    salesforce_v2_auth_params: Optional[SalesforceV2AuthParamsDTO] = Field(default=None, alias="salesforceV2AuthParams")
    service_now_auth_params: Optional[ServiceNowAuthParamsDTO] = Field(default=None, alias="serviceNowAuthParams")
    service_now_v2_auth_params: Optional[ServiceNowV2AuthParamsDTO] = Field(default=None, alias="serviceNowV2AuthParams")
    slack_auth_params: Optional[SlackAuthParamsDTO] = Field(default=None, alias="slackAuthParams")
    snowflake_auth_params: Optional[SnowflakeAuthParamsDTO] = Field(default=None, alias="snowflakeAuthParams")
    sql_server_auth_params: Optional[SqlServerAuthParamsDTO] = Field(default=None, alias="sqlServerAuthParams")
    success_factors_auth_params: Optional[SuccessFactorsAuthParamsDTO] = Field(default=None, alias="successFactorsAuthParams")
    tenant_domain_name: Optional[StrictStr] = Field(default=None, alias="tenantDomainName")
    ultimate_auth_params: Optional[UltimateAuthParamsDTO] = Field(default=None, alias="ultimateAuthParams")
    willow_auth_params: Optional[WillowAuthParamsDTO] = Field(default=None, alias="willowAuthParams")
    workday_auth_params: Optional[WorkdayAuthParamsDTO] = Field(default=None, alias="workdayAuthParams")
    workday_raas_auth_params: Optional[WorkdayRaasAuthParamsDTO] = Field(default=None, alias="workdayRaasAuthParams")
    zoom_auth_params: Optional[ZoomAuthParamsDTO] = Field(default=None, alias="zoomAuthParams")
    __properties: ClassVar[List[str]] = ["adpAuthParams", "authContext", "bambooAuthParams", "bigQueryAuthParams", "copyS3AuthParams", "dayforceV2AuthParams", "dimensionsAuthParams", "emptyAuthParams", "fusionAuthParams", "gongAuthParams", "googleSheetsAuthParams", "googleWorkspaceAuthParams", "greenhouseAuthParams", "hasUpdates", "icimsAuthParams", "internalS3AuthParams", "jdbcAuthParams", "jiraAuthParams", "leverAuthParams", "medalliaAuthParams", "ms365AuthParams", "mySqlAuthParams", "namelyAuthParams", "oracleDbAuthParams", "provider", "qualtricsAuthParams", "redshiftAuthParams", "s3AuthParams", "salesforceAuthParams", "salesforceV2AuthParams", "serviceNowAuthParams", "serviceNowV2AuthParams", "slackAuthParams", "snowflakeAuthParams", "sqlServerAuthParams", "successFactorsAuthParams", "tenantDomainName", "ultimateAuthParams", "willowAuthParams", "workdayAuthParams", "workdayRaasAuthParams", "zoomAuthParams"]

    @field_validator('auth_context')
    def auth_context_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['DefaultDataExtraction', 'WorkplaceDynamicsDataExtraction', 'Notification']):
            raise ValueError("must be one of enum values ('DefaultDataExtraction', 'WorkplaceDynamicsDataExtraction', 'Notification')")
        return value

    @field_validator('provider')
    def provider_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Bamboo', 'GoogleSheets', 'Greenhouse', 'Jira', 'Lever', 'Namely', 'Qualtrics', 'Salesforce', 'UKG', 'Workday', 'Icims', 'ServiceNow', 'Jdbc', 'BasicS3', 'InternalS3', 'CopyS3', 'Redshift', 'Snowflake', 'BigQuery', 'SqlServer', 'Dimensions', 'IcimsPartnerProviderRedshift', 'Willow', 'SuccessFactors', 'IcimsV2', 'ADP', 'WorkdayV2', 'ServiceNowV2', 'Medallia', 'Fusion', 'SalesforceV2', 'Gong', 'Zoom', 'GoogleCalendar', 'UKGV2', 'DayforceV2', 'GoogleActivityReport', 'Slack', 'MySql', 'WorkdayRaas', 'Microsoft365', 'GoogleWorkspace', 'OracleDb', 'SmartRecruiters', 'WorkdayWQL', 'OEMCornerstone']):
            raise ValueError("must be one of enum values ('Bamboo', 'GoogleSheets', 'Greenhouse', 'Jira', 'Lever', 'Namely', 'Qualtrics', 'Salesforce', 'UKG', 'Workday', 'Icims', 'ServiceNow', 'Jdbc', 'BasicS3', 'InternalS3', 'CopyS3', 'Redshift', 'Snowflake', 'BigQuery', 'SqlServer', 'Dimensions', 'IcimsPartnerProviderRedshift', 'Willow', 'SuccessFactors', 'IcimsV2', 'ADP', 'WorkdayV2', 'ServiceNowV2', 'Medallia', 'Fusion', 'SalesforceV2', 'Gong', 'Zoom', 'GoogleCalendar', 'UKGV2', 'DayforceV2', 'GoogleActivityReport', 'Slack', 'MySql', 'WorkdayRaas', 'Microsoft365', 'GoogleWorkspace', 'OracleDb', 'SmartRecruiters', 'WorkdayWQL', 'OEMCornerstone')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DataProviderAuthParamsDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of adp_auth_params
        if self.adp_auth_params:
            _dict['adpAuthParams'] = self.adp_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bamboo_auth_params
        if self.bamboo_auth_params:
            _dict['bambooAuthParams'] = self.bamboo_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of big_query_auth_params
        if self.big_query_auth_params:
            _dict['bigQueryAuthParams'] = self.big_query_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of copy_s3_auth_params
        if self.copy_s3_auth_params:
            _dict['copyS3AuthParams'] = self.copy_s3_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of dayforce_v2_auth_params
        if self.dayforce_v2_auth_params:
            _dict['dayforceV2AuthParams'] = self.dayforce_v2_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of dimensions_auth_params
        if self.dimensions_auth_params:
            _dict['dimensionsAuthParams'] = self.dimensions_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fusion_auth_params
        if self.fusion_auth_params:
            _dict['fusionAuthParams'] = self.fusion_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gong_auth_params
        if self.gong_auth_params:
            _dict['gongAuthParams'] = self.gong_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of google_sheets_auth_params
        if self.google_sheets_auth_params:
            _dict['googleSheetsAuthParams'] = self.google_sheets_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of google_workspace_auth_params
        if self.google_workspace_auth_params:
            _dict['googleWorkspaceAuthParams'] = self.google_workspace_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of greenhouse_auth_params
        if self.greenhouse_auth_params:
            _dict['greenhouseAuthParams'] = self.greenhouse_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of icims_auth_params
        if self.icims_auth_params:
            _dict['icimsAuthParams'] = self.icims_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of internal_s3_auth_params
        if self.internal_s3_auth_params:
            _dict['internalS3AuthParams'] = self.internal_s3_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of jdbc_auth_params
        if self.jdbc_auth_params:
            _dict['jdbcAuthParams'] = self.jdbc_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of jira_auth_params
        if self.jira_auth_params:
            _dict['jiraAuthParams'] = self.jira_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of lever_auth_params
        if self.lever_auth_params:
            _dict['leverAuthParams'] = self.lever_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of medallia_auth_params
        if self.medallia_auth_params:
            _dict['medalliaAuthParams'] = self.medallia_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ms365_auth_params
        if self.ms365_auth_params:
            _dict['ms365AuthParams'] = self.ms365_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of my_sql_auth_params
        if self.my_sql_auth_params:
            _dict['mySqlAuthParams'] = self.my_sql_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of namely_auth_params
        if self.namely_auth_params:
            _dict['namelyAuthParams'] = self.namely_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of oracle_db_auth_params
        if self.oracle_db_auth_params:
            _dict['oracleDbAuthParams'] = self.oracle_db_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of qualtrics_auth_params
        if self.qualtrics_auth_params:
            _dict['qualtricsAuthParams'] = self.qualtrics_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of redshift_auth_params
        if self.redshift_auth_params:
            _dict['redshiftAuthParams'] = self.redshift_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of s3_auth_params
        if self.s3_auth_params:
            _dict['s3AuthParams'] = self.s3_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of salesforce_auth_params
        if self.salesforce_auth_params:
            _dict['salesforceAuthParams'] = self.salesforce_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of salesforce_v2_auth_params
        if self.salesforce_v2_auth_params:
            _dict['salesforceV2AuthParams'] = self.salesforce_v2_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of service_now_auth_params
        if self.service_now_auth_params:
            _dict['serviceNowAuthParams'] = self.service_now_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of service_now_v2_auth_params
        if self.service_now_v2_auth_params:
            _dict['serviceNowV2AuthParams'] = self.service_now_v2_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of slack_auth_params
        if self.slack_auth_params:
            _dict['slackAuthParams'] = self.slack_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of snowflake_auth_params
        if self.snowflake_auth_params:
            _dict['snowflakeAuthParams'] = self.snowflake_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sql_server_auth_params
        if self.sql_server_auth_params:
            _dict['sqlServerAuthParams'] = self.sql_server_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of success_factors_auth_params
        if self.success_factors_auth_params:
            _dict['successFactorsAuthParams'] = self.success_factors_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ultimate_auth_params
        if self.ultimate_auth_params:
            _dict['ultimateAuthParams'] = self.ultimate_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of willow_auth_params
        if self.willow_auth_params:
            _dict['willowAuthParams'] = self.willow_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workday_auth_params
        if self.workday_auth_params:
            _dict['workdayAuthParams'] = self.workday_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workday_raas_auth_params
        if self.workday_raas_auth_params:
            _dict['workdayRaasAuthParams'] = self.workday_raas_auth_params.to_dict()
        # override the default output from pydantic by calling `to_dict()` of zoom_auth_params
        if self.zoom_auth_params:
            _dict['zoomAuthParams'] = self.zoom_auth_params.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DataProviderAuthParamsDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "adpAuthParams": AdpAuthParamsDTO.from_dict(obj["adpAuthParams"]) if obj.get("adpAuthParams") is not None else None,
            "authContext": obj.get("authContext"),
            "bambooAuthParams": BambooAuthParamsDTO.from_dict(obj["bambooAuthParams"]) if obj.get("bambooAuthParams") is not None else None,
            "bigQueryAuthParams": BigQueryAuthParamsDTO.from_dict(obj["bigQueryAuthParams"]) if obj.get("bigQueryAuthParams") is not None else None,
            "copyS3AuthParams": CopyS3AuthParamsDTO.from_dict(obj["copyS3AuthParams"]) if obj.get("copyS3AuthParams") is not None else None,
            "dayforceV2AuthParams": DayforceV2AuthParamsDTO.from_dict(obj["dayforceV2AuthParams"]) if obj.get("dayforceV2AuthParams") is not None else None,
            "dimensionsAuthParams": DimensionsAuthParamsDTO.from_dict(obj["dimensionsAuthParams"]) if obj.get("dimensionsAuthParams") is not None else None,
            "emptyAuthParams": obj.get("emptyAuthParams"),
            "fusionAuthParams": FusionAuthParamsDTO.from_dict(obj["fusionAuthParams"]) if obj.get("fusionAuthParams") is not None else None,
            "gongAuthParams": GongAuthParamsDTO.from_dict(obj["gongAuthParams"]) if obj.get("gongAuthParams") is not None else None,
            "googleSheetsAuthParams": GoogleSheetsAuthParamsDTO.from_dict(obj["googleSheetsAuthParams"]) if obj.get("googleSheetsAuthParams") is not None else None,
            "googleWorkspaceAuthParams": GoogleWorkspaceAuthParamsDTO.from_dict(obj["googleWorkspaceAuthParams"]) if obj.get("googleWorkspaceAuthParams") is not None else None,
            "greenhouseAuthParams": GreenhouseAuthParamsDTO.from_dict(obj["greenhouseAuthParams"]) if obj.get("greenhouseAuthParams") is not None else None,
            "hasUpdates": obj.get("hasUpdates"),
            "icimsAuthParams": IcimsAuthParamsDTO.from_dict(obj["icimsAuthParams"]) if obj.get("icimsAuthParams") is not None else None,
            "internalS3AuthParams": InternalS3AuthParamsDTO.from_dict(obj["internalS3AuthParams"]) if obj.get("internalS3AuthParams") is not None else None,
            "jdbcAuthParams": JdbcAuthParamsDTO.from_dict(obj["jdbcAuthParams"]) if obj.get("jdbcAuthParams") is not None else None,
            "jiraAuthParams": JiraAuthParamsDTO.from_dict(obj["jiraAuthParams"]) if obj.get("jiraAuthParams") is not None else None,
            "leverAuthParams": LeverAuthParamsDTO.from_dict(obj["leverAuthParams"]) if obj.get("leverAuthParams") is not None else None,
            "medalliaAuthParams": MedalliaAuthParamsDTO.from_dict(obj["medalliaAuthParams"]) if obj.get("medalliaAuthParams") is not None else None,
            "ms365AuthParams": Microsoft365AuthParamsDTO.from_dict(obj["ms365AuthParams"]) if obj.get("ms365AuthParams") is not None else None,
            "mySqlAuthParams": MySqlAuthParamsDTO.from_dict(obj["mySqlAuthParams"]) if obj.get("mySqlAuthParams") is not None else None,
            "namelyAuthParams": NamelyAuthParamsDTO.from_dict(obj["namelyAuthParams"]) if obj.get("namelyAuthParams") is not None else None,
            "oracleDbAuthParams": OracleDbAuthParamsDTO.from_dict(obj["oracleDbAuthParams"]) if obj.get("oracleDbAuthParams") is not None else None,
            "provider": obj.get("provider"),
            "qualtricsAuthParams": QualtricsAuthParamsDTO.from_dict(obj["qualtricsAuthParams"]) if obj.get("qualtricsAuthParams") is not None else None,
            "redshiftAuthParams": RedshiftAuthParamsDTO.from_dict(obj["redshiftAuthParams"]) if obj.get("redshiftAuthParams") is not None else None,
            "s3AuthParams": BasicS3AuthParamsDTO.from_dict(obj["s3AuthParams"]) if obj.get("s3AuthParams") is not None else None,
            "salesforceAuthParams": SalesforceAuthParamsDTO.from_dict(obj["salesforceAuthParams"]) if obj.get("salesforceAuthParams") is not None else None,
            "salesforceV2AuthParams": SalesforceV2AuthParamsDTO.from_dict(obj["salesforceV2AuthParams"]) if obj.get("salesforceV2AuthParams") is not None else None,
            "serviceNowAuthParams": ServiceNowAuthParamsDTO.from_dict(obj["serviceNowAuthParams"]) if obj.get("serviceNowAuthParams") is not None else None,
            "serviceNowV2AuthParams": ServiceNowV2AuthParamsDTO.from_dict(obj["serviceNowV2AuthParams"]) if obj.get("serviceNowV2AuthParams") is not None else None,
            "slackAuthParams": SlackAuthParamsDTO.from_dict(obj["slackAuthParams"]) if obj.get("slackAuthParams") is not None else None,
            "snowflakeAuthParams": SnowflakeAuthParamsDTO.from_dict(obj["snowflakeAuthParams"]) if obj.get("snowflakeAuthParams") is not None else None,
            "sqlServerAuthParams": SqlServerAuthParamsDTO.from_dict(obj["sqlServerAuthParams"]) if obj.get("sqlServerAuthParams") is not None else None,
            "successFactorsAuthParams": SuccessFactorsAuthParamsDTO.from_dict(obj["successFactorsAuthParams"]) if obj.get("successFactorsAuthParams") is not None else None,
            "tenantDomainName": obj.get("tenantDomainName"),
            "ultimateAuthParams": UltimateAuthParamsDTO.from_dict(obj["ultimateAuthParams"]) if obj.get("ultimateAuthParams") is not None else None,
            "willowAuthParams": WillowAuthParamsDTO.from_dict(obj["willowAuthParams"]) if obj.get("willowAuthParams") is not None else None,
            "workdayAuthParams": WorkdayAuthParamsDTO.from_dict(obj["workdayAuthParams"]) if obj.get("workdayAuthParams") is not None else None,
            "workdayRaasAuthParams": WorkdayRaasAuthParamsDTO.from_dict(obj["workdayRaasAuthParams"]) if obj.get("workdayRaasAuthParams") is not None else None,
            "zoomAuthParams": ZoomAuthParamsDTO.from_dict(obj["zoomAuthParams"]) if obj.get("zoomAuthParams") is not None else None
        })
        return _obj


